﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Infragistics.UltraChart.Core.Layers;
using Infragistics.UltraChart.Resources.Appearance;
using Infragistics.UltraChart.Shared.Styles;
using Infragistics.Web.UI.Framework.Persistence;
using Infragistics.Web.UI.GridControls;

namespace WebApplication1
{
    public partial class WebForm1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                // ************************************************
                // 初回ロード時にデータを生成しセッションに保存
                // ************************************************
                Session["Data"] = GetData();
                Session["Data2"] = GetData2();

                WebDropDown1.SelectedItemIndex = 0;


            }

            // ************************************************
            // チャートの各種設定
            // ************************************************
            //どのチャートタイプを利用するのか決定
            switch (WebDropDown1.SelectedValue.ToString())
            {
                case "StackColumnChart":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.StackColumnChart;
                    break;
                case "Stack3DColumnChart":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.Stack3DColumnChart;
                    break;
                case "LineChart":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.LineChart;
                    break;
                case "LineChart3D":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.LineChart3D;
                    break;
                case "StackAreaChart":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.StackAreaChart;
                    break;
                case "AreaChart3D":
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.AreaChart3D;
                    break;
                default:
                    this.UltraChart1.ChartType = Infragistics.UltraChart.Shared.Styles.ChartType.StackColumnChart;
                    break;
            }

            //X軸のラベルを縦表示に変更
            this.UltraChart1.Axis.X.Labels.SeriesLabels.Orientation = TextOrientation.VerticalLeftFacing;

            //凡例を表示
            this.UltraChart1.Legend.Visible = true;
            this.UltraChart1.Legend.SpanPercentage = 10;

            //バーの間隔を開ける
            UltraChart1.ColumnChart.ColumnSpacing = 1;

            //色を指定する
            Color[] ChartColors;
            ChartColors = new Color[] { 
                Color.FromArgb(196,131,0),
                Color.FromArgb(224,0,120),
                Color.FromArgb(0,171,169),
                Color.FromArgb(45,137,239),
                Color.FromArgb(95,25,89),
                Color.FromArgb(82,82,82)
            };
            UltraChart1.ColorModel.ModelStyle = ColorModels.CustomLinear;
            UltraChart1.ColorModel.CustomPalette = ChartColors;
            
            // ************************************************
            // チャートのデータバインド
            // ************************************************
            // チャートタイプによってバインドするデータの形式を変える
            switch (WebDropDown1.SelectedValue.ToString())
            {
                case "LineChart":
                case "LineChart3D":
                case "StackAreaChart":
                case "AreaChart3D":
                    this.UltraChart1.DataSource = Session["Data2"];
                    break;
                default:
                    this.UltraChart1.DataSource = Session["Data"];
                    break;
            }
            this.UltraChart1.Data.DataBind();

            // ************************************************
            // グリッドのデータバインド
            // ************************************************
            this.WebDataGrid1.DataSource = Session["Data"];
            this.WebDataGrid1.DataBind();

            // ************************************************
            // 外観テーマの設定
            // ************************************************            
            string theme = "IG";
            this.WebDataGrid1.StyleSetName = theme;
            this.WebDropDown1.StyleSetName = theme;


            //セッションからグリッドの情報を取り出し、適用する
            if (Session["gridInfo"] != null)
            {
                PersistenceManager manager = PersistenceManager.GetInstance();
                PersistenceData data = PersistenceData.FromJson(Session["gridInfo"].ToString());
                if (data != null)
                {
                    foreach (ControlData controlData in data.Controls)
                    {
                        if (!string.IsNullOrEmpty(controlData.ControlId))
                        {
                            Control control = this.FindControl(controlData.ControlId);
                            // コントロールに再度適用する
                            manager.LoadControl(control, controlData);
                        }
                    }
                }
            }
        }


        // ************************************************
        // 積層柱状グラフ用のデータを生成
        // ************************************************
        private DataTable GetData()
        {
            // ************************
            // Create DataSet
            // ************************

            //Create DataTable
            DataTable dtSample1 = new DataTable("Sample");

            //Create Columns
            dtSample1.Columns.Add("Date", typeof(System.String));
            dtSample1.Columns.Add("column1", typeof(System.Int32));
            dtSample1.Columns.Add("column2", typeof(System.Int32));
            dtSample1.Columns.Add("column3", typeof(System.Int32));
            dtSample1.Columns.Add("column4", typeof(System.Int32));
            dtSample1.Columns.Add("column5", typeof(System.Int32));
            dtSample1.Columns.Add("column6", typeof(System.Int32));

            //Create Rows
            for (int index = 0; index <= 20; index++)
            {
                dtSample1.Rows.Add(new object[] {
                                                    DateTime.Now.AddDays(index).ToString("yyyy/MM/dd"),
                                                    (index+11)*(index+22)%35,
                                                    (index+22)*(index+33)%70,
                                                    (index+33)*(index+44)%100,
                                                    (index+44)*(index+55)%150,
                                                    (index+55)*(index+66)%200,
                                                    (index+66)*(index+77)%300
                                                });
            }
            dtSample1.PrimaryKey = new DataColumn[] { dtSample1.Columns["Date"] };

            return dtSample1;
        }

        // ************************************************
        // 積層柱状グラフ用のデータを他の形式へ変換する関数
        // ************************************************
        private DataTable GetData2()
        {
            // ************************
            // Create DataSet
            // ************************

            //Create DataTable
            DataTable dtSample1 = new DataTable("Sample");

            //Create Columns
            dtSample1.Columns.Add("Type", typeof(System.String));
            DataTable dt = GetData();
            foreach (DataRow row in dt.Rows)
            {
                dtSample1.Columns.Add(row["Date"].ToString(), typeof(System.Int32));
            }
            //Create Rows
            for (int index = 1; index <= dt.Columns.Count - 1; index++)
            {
                DataRow newRow = dtSample1.Rows.Add(new object[] {
                                                    dt.Columns[index].ColumnName
                                                });

                for (int index2 = 0; index2 <= dt.Rows.Count - 1; index2++)
                {
                    newRow[index2 + 1] = dt.Rows[index2][dt.Columns[index].ColumnName];
                }
            }
            dtSample1.PrimaryKey = new DataColumn[] { dtSample1.Columns["Type"] };

            return dtSample1;
        }

        // ************************************************
        // Excel出力
        // ************************************************
        protected void LinkButton1_Click(object sender, EventArgs e)
        {
            //チャートから画像を出力する
            string fileName = "chartImageForExport.bmp";
            UltraChart1.SaveTo(fileName, System.Drawing.Imaging.ImageFormat.Bmp);

            //Saveした画像の取得
            System.Drawing.Image image = System.Drawing.Image.FromFile(fileName);
            Infragistics.Documents.Excel.WorksheetImage imageShape =
              new Infragistics.Documents.Excel.WorksheetImage(image);

            //Excel出力用のワークブックとワークシートを準備
            Infragistics.Documents.Excel.Workbook workbook = new Infragistics.Documents.Excel.Workbook();
            Infragistics.Documents.Excel.Worksheet worksheet1 = workbook.Worksheets.Add("Sheet1");

            // チャート画像出力先の開始位置の指定
            Infragistics.Documents.Excel.WorksheetCell cellB2 = worksheet1.Rows[1].Cells[1]; //チャート画像の出力先の開始位置
            imageShape.TopLeftCornerCell = cellB2;
            imageShape.TopLeftCornerPosition = new PointF(0.0F, 0.0F);

            // チャート画像出力先の終了位置の指定
            Infragistics.Documents.Excel.WorksheetCell cellJ17 = worksheet1.Rows[16].Cells[9]; //チャート画像の出力先の終了位置
            imageShape.BottomRightCornerCell = cellJ17;
            imageShape.BottomRightCornerPosition = new PointF(100.0F, 100.0F);

            // シートに画像を追加
            worksheet1.Shapes.Add(imageShape);
            
            //Worksheet1の19行目のB列目からグリッドの内容をエクスポート（レスポンスヘッダは書きかえない）
            WebExcelExporter1.Export(worksheet1, 18, 1, WebDataGrid1);

            // ******************************************
            // エクセル出力
            // ******************************************
            // メモリストリーム
            System.IO.MemoryStream theStream = new System.IO.MemoryStream();

            // ストリームに作成したワークブックを保存
            workbook.Save(theStream);

            // レスポンスヘッダの書きかえ
            byte[] byteArr = (byte[])Array.CreateInstance(typeof(byte), theStream.Length);
            theStream.Position = 0;
            theStream.Read(byteArr, 0, (int)theStream.Length);
            theStream.Close();
            Response.Clear();
            Response.AddHeader("content-disposition", "attachment; filename=ExportedTo.xlsx");
            Response.BinaryWrite(byteArr);
            Response.End();
        }

        // ************************************************
        // PDF出力
        // ************************************************
        protected void LinkButton2_Click(object sender, EventArgs e)
        {
            //try
            //{
            //    WebDocumentExporter1.Format = Infragistics.Web.UI.GridControls.FileFormat.PDF;
            //    WebDocumentExporter1.Export(WebDataGrid1);
            //}
            //catch{ }

            //グリッドの情報をJson形式でエクスポートし、セッションに保存
            PersistenceData data = new PersistenceData();
            PersistenceManager manager = PersistenceManager.GetInstance();
            data.Controls.Add(manager.SaveControl(WebDataGrid1, WebDataGrid1.ID));
            Session["gridInfo"] = data.ToJson();
        }

        protected void WebDataGrid1_InitializeRow(object sender, RowEventArgs e)
        {
            //右づめ設定
            e.Row.Items[1].CssClass = "RightAlign";
            e.Row.Items[2].CssClass = "RightAlign";
            e.Row.Items[3].CssClass = "RightAlign";
            e.Row.Items[4].CssClass = "RightAlign";
            e.Row.Items[5].CssClass = "RightAlign";
            e.Row.Items[6].CssClass = "RightAlign";
        }

        protected void UltraChart1_ChartDataDoubleClicked(object sender, Infragistics.UltraChart.Shared.Events.ChartDataEventArgs e)
        {
            
        }

        protected void UltraChart1_ChartDataClicked(object sender, Infragistics.UltraChart.Shared.Events.ChartDataEventArgs e)
        {

        }

        protected void WebDataGrid1_DataFiltered(object sender, FilteredEventArgs e)
        {
            System.Diagnostics.Debug.WriteLine("DataFiltered");
        }
    }
}